clear 
capture log close
set more off

local onecrop=1
local twocrop=1
local graph=1

foreach v in C K L M N {
forval c =1/2 {
insheet using "$original\\`v'_`c'.csv", c clear
gen crop=`c' //
gen village="`v'"
save "$data\\`v'_`c'", replace
}
}

u "$data\C_1", clear
foreach x in C_2 K_1 K_2 L_1 L_2 M_1 M_2 N_1 N_2 {
append using "$data\\`x'" 
}
ren cropwatersatisfactionindex cwsi
ren  harvestyear year
gen cropcode="maize" if crop==2
replace cropcode="gnut" if crop==1
gen one=1
drop if cwsi==.
save "$data\shock", replace

foreach x in C_1 C_2 K_1 K_2 L_1 L_2 M_1 M_2 N_1 N_2 {
erase "$data\\`x'.dta"
}

u "$data\shock", clear

/********************* GRAPH CWSI *******************/
if `graph'>0 {
histogram cwsi, fcolor(gs9) lcolor(gs10) scheme(s1color) plotr(lw(none) ilw(none)) xtitle("Crop Water Stress Index") saving($graph\hist1k, replace)
graph export "$graph\hist1k.pdf", replace

twoway (histogram cwsi if crop==1, fcolor(none) lp(dash) lcolor(black) lw(medthick) scheme(s1color) plotr(lw(none) ilw(none)) xtitle("Crop Water Stress Index")) ///
(histogram cwsi if crop==2, fcolor(none) lcolor(blue) lw(medthick) legend(order(1 "Traditional" 2 "Hybrid")) saving($graph\hist2k, replace)) 
graph export "$graph\hist2k.pdf", replace

graph drop _all
}

/******************* ONE CROP ONLY *******************/

if `onecrop'>0 {
u "$data\shock", clear

log using "$result\shock_rainfall", t replace
sum cwsi, d
log close

preserve
bys year: egen sim=mean(cwsi)
keep year sim
duplicates drop
outsheet sim using "$math\shocksim.dat", replace noname
restore

sort cwsi
gen bin=1 
replace bin=2 in 2/139
replace bin=3 in 140/277
replace bin=4 in 278/415
replace bin=5 in 416

gen binlong=1 
replace binlong=2 in 2/70
replace binlong=3 in 71/139
replace binlong=4 in 140/208
replace binlong=5 in 209/277
replace binlong=6 in 278/346
replace binlong=7 in 347/415
replace binlong=8 in 416

bys binlong: egen numlong=total(one)
bys bin: egen num=total(one)
egen den=total(one)
bys bin: egen value=mean(cwsi)
bys binlong: egen valuelong = mean(cwsi)
gen proplong=numlong/den
gen prop=num/den

preserve
keep valuelong proplong
duplicates drop
outsheet prop using "$math\proplong.dat", replace noname
outsheet value using "$math\vallong.dat", replace noname
restore
keep value prop
duplicates drop
outsheet prop using "$math\prop.dat", replace noname
outsheet value using "$math\val.dat", replace noname

}

/********************* TWO CROPS: HYBRID AND TRADITIONAL *******************/

if `twocrop'>0 {
u "$data\shock", clear
preserve
bys year crop: egen sim=mean(cwsi) 
keep year sim crop
duplicates drop
reshape wide sim, i(year) j(crop)
outsheet sim1 using "$math\shocksimT.dat", replace noname
outsheet sim2 using "$math\shocksimH.dat", replace noname
restore

log using "$result\shock_rainfall", t append
bys cropcode: sum cwsi*, d
log close
drop cropcode

reshape wide cwsi, i(year village) j(crop)
save "$data\temp", replace

foreach x in 1 2 {
u "$data\temp", clear
sort cwsi`x'

gen bin`x'=1 
replace bin`x'=2 in 2/30
replace bin`x'=3 in 31/60
replace bin`x'=4 in 61/89
replace bin`x'=5 in 90/119
replace bin`x'=6 in 120/148
replace bin`x'=7 in 149/178
replace bin`x'=8 in 179/207
replace bin`x'=9 in 208

bys bin`x': egen num`x'=total(one)
egen den`x'=total(one)
bys bin: egen value`x'=mean(cwsi`x')

gen prop`x'=num`x'/den`x'
keep value`x' prop`x'
duplicates drop
outsheet prop`x' using "$math\prop`x'.dat", replace noname
outsheet value`x' using "$math\val`x'.dat", replace noname
}

erase "$data\temp.dta"
}


